@@ -338,7 +338,7 @@ class BP3EnsemblePredict():
                 with torch.no_grad():
                 
                     model_state = self.model_states[i] 
-                    model.load_state_dict(torch.load(model_state))
+                    model.load_state_dict(torch.load(model_state, map_location=self.device))
                     model = model.to(self.device)
                     model.eval()
                     model_output = model(esm1b_encoding)
